import Handler from './Handler';
/**
 * 全局的事件处理器
 */
declare class EventHandler {
    /** @ignore */
    handler: Handler;
    /** @ignore */
    panning: boolean;
    /** @ignore */
    constructor(handler: Handler);
    /** @ignore */
    initialize(): void;
    /**
     * 画布元素修改事件的回调，需要在初始化的时候注册
     */
    private modified;
    /**
     * 鼠标点击事件的回调，需要在初始化的时候注册
     */
    private mouseDown;
    /**
     * 鼠标移动事件
     * @param opt event事件
     */
    private mouseMove;
    /**
     * 鼠标按键抬起事件
     */
    private mouseUp;
    /**
     * 元素缩放事件
     */
    private scaling;
    /**
     * afterRender事件
     */
    private afterRender;
    /**
     * beforeRender事件
     */
    private beforeRender;
    /**
     * 方向键移动
     * @param e 事件
     * @returns 无
     */
    arrowMoving(opt: KeyboardEvent): void;
    /**
     * 键盘按键事件
     */
    private keydown;
    /**
     * 复制画布元素
     * @param obj 需被复制的画布元素，不传入时默认画布中当前选择的元素
     * @param callback clone完成后的callback
     * @returns
     */
    copy(defaultPaste?: boolean): void;
    /**
     * 黏贴事件
     */
    paste(opt: ClipboardEvent): Promise<void>;
    private isDom;
    private isJson;
    private pasteImage;
    /**
     * 裁剪元素事件
     */
    private cut;
    /**
     * 鼠标滚轮事件
     */
    private wheel;
    /**
     * 当窗口大小改变时，通过设置元素的偏移，来达到视窗效果的不变
     * @param nextWidth 改变后的宽度
     * @param nextHeight 改变后的高度
     */
    resize(nextWidth: number, nextHeight: number): void;
}
export default EventHandler;
