import { fabric } from 'fabric';
import ParsePSDHandler from './ParsePSDHandler';
import RenderHandler from './RenderHandler';
import ZoomHandler from './ZoomHandler';
import WorkareaHandler from './WorkareaHandler';
import CommonHandler from './CommonHandler';
import ParseSketchHandler from './ParseSketchHandler';
import ParseFigmaHandler from './ParseFigmaHandler';
import TransactionHandler from './TransactionHandler';
import EventHandler from './EventHandler';
import EffectHandler from './EffectHandler';
import InteractionHandler from './InteractionHandler';
import CropImageHandler from './CropImageHandler';
import RenderLayerHandler from './RenderLayerHandler';
import RulerHandler from './RulerHandler';
import FilterHandler from './FilterHandler';
import LayerHandler from './LayerHandler';
import FigureHandler from './FigureHandler';
import ImageClipPathHandler from './ImageClipPathHandler';
import GroupHandler from './GroupHandler';
import AlignHandler from './AlignHandler';
import ExportHandler from './ExportHandler';
import ControlHandler from './ControlHandler';
import ShortcutHandler from './ShortcutHandler';
import { IKeyEvent } from '../interface';
type OnModified = (target: fabric.Object, key?: string, value?: string | boolean) => void;
type onSelect = (target?: fabric.Object, type?: string) => void;
interface IHandlerCallback {
    onModified?: OnModified;
    onSelect?: onSelect;
}
interface IHandlerOption {
    canvas?: fabric.Canvas;
}
/** @ignore */
export type HandlerOptions = IHandlerOption & IHandlerCallback;
/**
 * 入口处理器，接收用户的定制内容和回调
 */
declare class Handler implements HandlerOptions {
    /** @ignore */
    canvas: fabric.Canvas;
    /** @ignore */
    propertiesToInclude?: string[];
    /** @ignore */
    keyEvent?: IKeyEvent;
    interactionMode: string;
    canvasColors: string[];
    /** @ignore */
    parsePSDHandler: ParsePSDHandler;
    /** @ignore */
    parseSketchHandler: ParseSketchHandler;
    /** @ignore */
    parseFigmaHandler: ParseFigmaHandler;
    /** @ignore */
    renderHandler: RenderHandler;
    /** @ignore */
    zoomHandler: ZoomHandler;
    /** @ignore */
    workareaHandler: WorkareaHandler;
    /** @ignore */
    commonHandler: CommonHandler;
    /** @ignore */
    transactionHandler: TransactionHandler;
    /** @ignore */
    eventHandler: EventHandler;
    /** @ignore */
    effectHandler: EffectHandler;
    /** @ignore */
    interactionHandler: InteractionHandler;
    /** @ignore */
    cropImageHandler: CropImageHandler;
    /** @ignore */
    rulerHandler: RulerHandler;
    /** @ignore */
    renderLayerHandler: RenderLayerHandler;
    /** @ignore */
    filterHandler: FilterHandler;
    /** @ignore */
    layerHandler: LayerHandler;
    /** @ignore */
    figureHandler: FigureHandler;
    /** @ignore */
    imageClipPathHandler: ImageClipPathHandler;
    /** @ignore */
    groupHandler: GroupHandler;
    /** @ignore */
    alignHandler: AlignHandler;
    /** @ignore */
    exportHandler: ExportHandler;
    /** @ignore */
    controlHandler: ControlHandler;
    /** @ignore */
    shortcutHandler: ShortcutHandler;
    /**
     * 当画布修改以后的回调
     * @param  target - 修改的画布元素
     * @param key - 修改的属性
     * @param value - 修改的值
     */
    onModified?: (target: fabric.Object, key?: string, value?: string | boolean) => void;
    /**
     * 选择画布中元素的回调
     * @param  target - 选择的元素
     * @param type - 选择的元素类型
     */
    onSelect?: (target?: fabric.Object, type?: string) => void;
    /** @ignore */
    constructor(options: HandlerOptions);
    private initOption;
    private initHandler;
    private initCallback;
}
export default Handler;
